netapp_ontap.models.shelf_frus API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.shelf_frus`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ShelfFrusSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ShelfFrus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `firmware_version GET POST PATCH`

    The firmware_version field of the shelf_frus.

    Example: 191.0

  `id GET POST PATCH`

    The id field of the shelf_frus.

  `part_number GET POST PATCH`

    The part_number field of the shelf_frus.

    Example: 111-00690+A2

  `serial_number GET POST PATCH`

    The serial_number field of the shelf_frus.

    Example: 8000166294

  `state GET POST PATCH`

    The state field of the shelf_frus.

    Valid choices:

    - ok
    - error
  `type GET POST PATCH`

    The type field of the shelf_frus.

    Valid choices:

    - module
    - psu